KrySA
=====

<img align="right" height="256" src="https://raw.githubusercontent.com/KeyWeeUsr/KrySA/master/krysa/data/logo.png"/>

<a href="http://krysa.readthedocs.io/en/latest/" target="_blank">
<img src="https://readthedocs.org/projects/krysa/badge/?version=latest" /></a>
<a href="https://pypi.python.org/pypi/krysa" target="_blank">
<img src="https://img.shields.io/pypi/pyversions/krysa.svg" /></a>
<a href="https://pypi.python.org/pypi/krysa" target="_blank">
<img src="https://img.shields.io/pypi/v/krysa.svg" /></a>

_Statistical analysis for rats._

A common translation of the word "krysa" is "a rat", mostly considered a lower
creature, but in fact a really cute and intelligent little rodent.

The idea behind KrySA is to make statistical software available even for the
"rats" - people who can't or don't want to buy a commercial tool for statistics
for whatever reason. KrySA is a free, open-source tool that anyone can afford!

KrySA is written in [Python 2.7](https://python.org) using
[Kivy](https://kivy.org) framework together with
[packages](http://krysa.readthedocs.io/en/latest/gettingstarted.html).
To run it you have to have all of them installed.

Licenses
--------

- KrySA is released under GNU GPL v3.0 License. Please read the
  [LICENSE](https://github.com/KeyWeeUsr/KrySA/blob/master/LICENSE.txt) file.
- The original logo concept is based on [OpenClipArt](www.openclipart.org)'s
  CC0 licensed image.

For more info about KrySA's license and licenses of used packages, please visit
the [documentation](http://krysa.readthedocs.io/en/latest/license.html).
